# Changelog

## [0.0.3a1](https://github.com/OpenVoiceOS/ovos-lang-parser/tree/0.0.3a1) (2025-06-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-lang-parser/compare/0.0.2...0.0.3a1)

**Merged pull requests:**

- nl-nl translation [\#12](https://github.com/OpenVoiceOS/ovos-lang-parser/pull/12) ([gitlocalize-app[bot]](https://github.com/apps/gitlocalize-app))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
